package org.ddahl

import shallot.parameter.partition.Partition
import shallot.parameter.Permutation
import rscala.PersistentReference

package object shallot {

  val Version = "0.4.0"

  val Date = "2017-08-22"

}

